@@ -1,8 +1,6 @@
 #' Load Packages
 #'
-#' Loads packages [It is assumed that the package(s) that you are wishing to
-#' load already exist in your library(ies). If not, then use the install_load
-#' function to install and then load the packages.]
+#' Loads the listed packages only
 #'
 #' @param package1 R package.
 #' @param ... Any additional R packages.
@@ -12,41 +10,46 @@
 #'
 #' @author maloneypatr, Irucka Embry
 #'
-#' @source Check if R package is installed then load library answered by
+#' @source
+#' \enumerate{
+#'    \item Check if R package is installed then load library answered by
 #'	maloneypatr is the source for the original function. See
 #'	\url{http://stackoverflow.com/questions/15155814/check-if-r-package-is-installed-then-load-library}.
+#'    \item Error Handling in R By Nina Zumel, October 9, 2012, R-Bloggers. See
+#'    \url{http://www.r-bloggers.com/error-handling-in-r/}.
+#' }
 #'
 #'
+#' @encoding UTF-8
 #'
-#' @seealso \code{\link{install_load}}
+#' @seealso \code{\link{install_load}} if you are wanting to install and load packages
 #'
 #'
 #'
 #' @examples
 #' \dontrun{
 #' library(install.load)
-#' # This will only load the package(s), so the packages should already be
-#' # available in your library(ies)
+#' # This will only load the package(s)
 #' load_package("chron")
-
+#'
 #' load_package("chron", "data.table", "dataRetrieval", "EGRET", "dplyr")
 #' }
 #'
 #'
 #'
 #' @export
-# Source begins
+# Source 1 begins
 load_package <- function (package1, ...) {
 
 
   # convert arguments to vector
   packages <- c(package1, ...)
 
-  # start loop to determine if each package is installed
+  # start loop to attempt to load each package
   for (package in packages) {
 
-      do.call("library", list(package))
+      try(do.call(library, list(package))) # Source 2
 
     }
   }
-# Source ends
+# Source 1 ends
